@@ -11,10 +11,12 @@ class RichErrorReportingPlugin(ErrorClassPlugin):
     name = "rich-errors"
     
     # Define error classes that we handle
-    broken = ErrorClass(BrokenTestException, label='BROKEN', isfailure=True)
-    excluded = ErrorClass(ExcludeTestException, label='XCLUDE', isfailure=False) #TODO better label; be able to customise the shortcut letter?
-    misconfigured = ErrorClass(InvalidTestConfigurationException, label='CONFIG_WRONG', isfailure=False) #TODO better label
+    #TODO Be able to customise the single letter labels
+    broken = ErrorClass(BrokenTestException, label='BROKEN', isfailure=False) #TODO should this be a failure? If so, we want to stop displaying tracebacks for it.
+    excluded = ErrorClass(ExcludeTestException, label='XCLUDE', isfailure=False) #TODO better label
     irrelevant = ErrorClass(IrrelevantTestException, label='IRRELEVANT', isfailure=False)
+    misconfigured = ErrorClass(InvalidTestConfigurationException, label='CONFIG_WRONG', isfailure=True) #TODO better label
+    unimplemented = ErrorClass(NotImplementedError, label="UNIMPLEMENTED", isFailure=False) #TODO should this be a failure? If so, we want to stop displaying tracebacks for it.
     
     # Use default implementation of options() and configure to enable this plugin
     
